@@ -3,14 +3,14 @@ import ipywidgets as widgets
 
 from traitlets import Unicode, Instance
 
-from .maps import Map, InitialViewport
+from .maps import Map, InitialViewport, GMapsWidgetMixin
 from .toolbar import Toolbar
 from .errors_box import ErrorsBox
 
 __all__ = ["Figure", "figure"]
 
 
-class Figure(widgets.DOMWidget):
+class Figure(GMapsWidgetMixin, widgets.DOMWidget):
     """
     Figure widget
 
@@ -19,9 +19,7 @@ class Figure(widgets.DOMWidget):
     factory method.
     """
     _view_name = Unicode("FigureView").tag(sync=True)
-    _view_module = Unicode("jupyter-gmaps").tag(sync=True)
     _model_name = Unicode("FigureModel").tag(sync=True)
-    _model_module = Unicode("jupyter-gmaps").tag(sync=True)
     _toolbar = Instance(Toolbar, allow_none=True, default=None).tag(
         sync=True, **widgets.widget_serialization)
     _errors_box = Instance(ErrorsBox, allow_none=True, default=None).tag(
@@ -55,6 +53,15 @@ class Figure(widgets.DOMWidget):
 
             :func:`gmaps.directions_layer`
                 Create a layer with directions
+
+            :func:`gmaps.bicycling_layer`
+                Create a layer showing cycle routes
+
+            :func:`gmaps.transit_layer`
+                Create a layer showing public transport
+
+            :func:`gmaps.traffic_layer`
+                Create a layer showing current traffic information
         """
         self._map.add_layer(layer)
 
