@@ -3,9 +3,9 @@ import ipywidgets as widgets
 
 from traitlets import Unicode
 
+from .maps import GMapsWidgetMixin
 
-class Toolbar(widgets.DOMWidget):
+
+class Toolbar(GMapsWidgetMixin, widgets.DOMWidget):
     _view_name = Unicode("ToolbarView").tag(sync=True)
-    _view_module = Unicode("jupyter-gmaps").tag(sync=True)
     _model_name = Unicode("ToolbarModel").tag(sync=True)
-    _model_module = Unicode("jupyter-gmaps").tag(sync=True)
